Usage from the Zope ZMI — Products.ZMySQLDA 4.0b2.dev0 documentation

# Usage from the Zope ZMI

The database connection object can be manipulated in the Zope ZMI on a series of screens, accessible through named tabs in the main window.

## Status

Shows the database connection status and allows the user to open or close the connection.

## Properties

Edit the database connection attributes and apply any changes:

- Title: An optional title that shows up in the ZMI.
- Database Connection String: A string encapsulating how to connect to the database. See Connection Strings for details.
- Connect immediately: Should the database connection be established immediately or when the first database query is run.
- Unicode Support: If set to `True`, values from columns of type `CHAR`, `VARCHAR` and `TEXT` are returned as unicode strings by the database backend. Combined with the hardcoded `UTF-8` character set of this package the setting allows you to control the character set of database return values better. Try enabling it if you are seeing character set/string encoding issues.
- Automatically create database: If the Database Connection String refers to a database that does not yet exist and this setting is activated, the ZMySQLDA connector will attempt to create the database.

## Test

The Test tab can be used as long as the database connection is connected. You can enter SQL statements into the text field and view the results sent back from the database.

## Security

Change the Zope role to permission mappings here.

## Undo

If your particular ZODB flavor supports it, you can undo Zope transactions affecting the database connector object here. These transactions don’t reflect relational database transactions in the underlying MySQL or MariaDB databases, only ZODB transactions.

## Ownership

Information about the Zope user who owns the database connector object. Ownership in the Zope sense confers additional rights.

## Interfaces

View and change the Zope Interface assignments for the database connector object.

## Browse

You can browse the database tables and columns from the relational database specified in the connection string.